@@ -155,7 +155,7 @@ class Algorithms:
         frame = np.clip(frame, blacklevel, whitelevel)
         t0 = time.time()
         frame -= blacklevel
-        frame /= whitelevel - blacklevel
+        frame = frame.astype(np.float32) / (whitelevel - blacklevel)
         ranges = f"{minmax} => [{blacklevel:.2f}, {whitelevel:.2f}] => {self._minmax(frame)}"
         self._vprint(f"{_elapsed(t0)} - linearizing: range = {ranges}")
         return frame
